Discover Packages
github.com/trianalab/pacto
pkg
override
package
Version:
v1.3.1
Opens a new window with list of versions in this module.
Published: Apr 9, 2026
License: MIT
Opens a new window with license information.
Imports: 5
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
Documentation
¶
Apply merges overrides into raw YAML data and returns the merged result.
Precedence (lowest to highest): base YAML < value files (in order) < --set values.
type Overrides struct {
ValueFiles []string
SetValues []string
}
Overrides holds the override configuration from CLI flags.
IsEmpty returns true if no overrides are configured.
Source Files
¶
Click to show internal directories.
Click to hide internal directories.